# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

try:
    from trytond.modules.account_fr_chorus.tests.test_account_fr_chorus import suite  # noqa: E501
except ImportError:
    from .test_account_fr_chorus import suite

__all__ = ['suite']



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.pool import PoolMeta


class Cron(metaclass=PoolMeta):
    __name__ = 'ir.cron'

    @classmethod
    def __setup__(cls):
        super().__setup__()
        cls.method.selection.append(
            ('account.invoice.chorus|send', "Send invoices to Chorus"))



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.pool import Pool
from . import account
from . import party
from . import edocument
from . import ir

__all__ = ['register']


def register():
    Pool.register(
        account.Configuration,
        account.CredentialChorus,
        account.Invoice,
        account.InvoiceChorus,
        party.Party,
        ir.Cron,
        module='account_fr_chorus', type_='model')
    Pool.register(
        edocument.UNCEFACTInvoice,
        module='account_fr_chorus', type_='model',
        depends=['edocument_uncefact'])
    Pool.register(
        module='account_fr_chorus', type_='wizard')
    Pool.register(
        module='account_fr_chorus', type_='report')



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.pool import PoolMeta
from trytond.model import fields


class Party(metaclass=PoolMeta):
    __name__ = 'party.party'

    chorus = fields.Boolean(
        "Chorus Pro",
        help="Send documents for this party through Chorus Pro")

    @classmethod
    def default_chorus(cls):
        return False



# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.pool import PoolMeta
from trytond.transaction import Transaction


class UNCEFACTInvoice(metaclass=PoolMeta):
    __name__ = 'edocument.uncefact.invoice'

    def render(self, template):
        if Transaction().context.get('account_fr_chorus') and not template:
            template = '16B-CII'
        return super(UNCEFACTInvoice, self).render(template)

    @classmethod
    def party_legal_ids(cls, party, address):
        ids = super(UNCEFACTInvoice, cls).party_legal_ids(party, address)
        if Transaction().context.get('account_fr_chorus') and address:
            ids.append((address.siret, {'schemeID': '1'}))
        return ids
